//
//  DataTextView.h
//  HexFiend
//
//  Created by ridiculous_fish on 9/2/04.
//  Copyright 2004-2006 ridiculous_fish. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@interface NSObject (CommanderProtocol)

- (NSArray*)writablePasteboardTypes;
- (BOOL)writeSelectionToPasteboard:(NSPasteboard*)pboard type:(NSString *)type;
- (void)copyToPasteboard:(NSPasteboard *)pboard;
- (void)resizingTextViewWithOldSize:(NSSize)size;

//range is given in my coordinates
- (void)insertText:(NSString*)text previousData:data;
//returns whether selection change is OK
- (BOOL)setTextSelection:(NSRange)range stillSelecting:(BOOL)flag;

//extends the selection as if the user moved the mouse to the character at index
//returns the new text selection range
- (NSRange)extendTextSelectionToTextViewCharacterIndex:(unsigned)index stillSelecting:(BOOL)stillSelecting;

- (BOOL)suppressTextFrameChanges:view;

- (BOOL)isCurrentlySettingSelection;

- (BOOL)performTextDragOperation:(id <NSDraggingInfo>)draggingInfo intoTextIndex:(unsigned)textIndex;

- (NSFont *)textFont;

@end

@interface DataTextView : NSTextView {
	id myCommander; //not retained
	unichar myLastTypedCharacter;
	BOOL mySelectedRangeIsOffscreen;
	unsigned myNextTextSelectionSuppressionCount;

	unsigned myMouseDownNumber;
	unsigned myBlockingMouseDownNumber;
	
	unsigned mySeparatorCount;
	
	unsigned myIsWithinDrag;
}

- (void)setCommander:commander;
- (id)myCommander;

- (void)blockAppKitRangeSettingForRemainderOfThisEvent;

//forgets any "pending" state (e.g. having typed the first nybble of a byte in hex mode)
- (void)forgetNextByteState;

//we only draw separators in the hex view
- (void)setSeparatorCount:(unsigned)count;

//return the amount that we want the insertion point to be offset, so that it's centered within spaces
- (BCFloat)horizontalInsertionPointOffset;

- (unsigned)glyphIndexForPoint:(NSPoint)point inTextContainer:(NSTextContainer *)container fractionOfDistanceThroughGlyph:(float *)partialFraction proposedIndex:(unsigned)proposedIndex;

@end


